=begin
#Nodeum API

#The Nodeum API makes it easy to tap into the digital data mesh that runs across your organisation. Make requests to our API endpoints and we’ll give you everything you need to interconnect your business workflows with your storage.  All production API requests are made to:  http://nodeumhostname/api/  The current production version of the API is v1.   **REST** The Nodeum API is a RESTful API. This means that the API is designed to allow you to get, create, update, & delete objects with the HTTP verbs GET, POST, PUT, PATCH, & DELETE.  **JSON** The Nodeum API speaks exclusively in JSON. This means that you should always set the Content-Type header to application/json to ensure that your requests are properly accepted and processed by the API.  **Authentication** All API calls require user-password authentication.   **Cross-Origin Resource Sharing** The Nodeum API supports CORS for communicating from Javascript for these endpoints. You will need to specify an Origin URI when creating your application to allow for CORS to be whitelisted for your domain.   **Pagination** Some endpoints such as File Listing return a potentially lengthy array of objects. In order to keep the response sizes manageable the API will take advantage of pagination. Pagination is a mechanism for returning a subset of the results for a request and allowing for subsequent requests to “page” through the rest of the results until the end is reached. Paginated endpoints follow a standard interface that accepts two query parameters, limit and offset, and return a payload that follows a standard form. These parameters names and their behavior are borrowed from SQL LIMIT and OFFSET keywords.  **Versioning** The Nodeum API is constantly being worked on to add features, make improvements, and fix bugs. This means that you should expect changes to be introduced and documented.   However, there are some changes or additions that are considered backwards-compatible and your applications should be flexible enough to handle them. These include:  - Adding new endpoints to the API - Adding new attributes to the response of an existing endpoint - Changing the order of attributes of responses (JSON by definition is an object of unordered key/value pairs)  **Filter parameters** When browsing a list of items, multiple filter parameters may be applied. Some operators can be added to the value as a prefix:  - `=` value is equal. Default operator, may be omitted  - `!=` value is different  - `>` greater than  - `>=` greater than or equal  - `<` lower than  - `>=` lower than or equal  - `><` included in list, items should be separated by `|`  - `!><` not included in list, items should be separated by `|`  - `~` pattern matching, may include `%` (any characters) and `_` (one character)  - `!~` pattern not matching, may include `%` (any characters) and `_` (one character)  

The version of the OpenAPI document: 2.1.0
Contact: info@nodeum.io
Generated by: https://openapi-generator.tech
OpenAPI Generator version: 4.3.0

=end

require 'cgi'

module Nodeum
  class CloudConnectorsApi
    attr_accessor :api_client

    def initialize(api_client = ApiClient.default)
      @api_client = api_client
    end
    # Creates a new cloud connector.
    # **API Key Scope**: cloud_connectors / create
    # @param cloud_connector_body [CloudConnector] 
    # @param [Hash] opts the optional parameters
    # @return [CloudConnector]
    def create_cloud_connector(cloud_connector_body, opts = {})
      data, _status_code, _headers = create_cloud_connector_with_http_info(cloud_connector_body, opts)
      data
    end

    # Creates a new cloud connector.
    # **API Key Scope**: cloud_connectors / create
    # @param cloud_connector_body [CloudConnector] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(CloudConnector, Integer, Hash)>] CloudConnector data, response status code and response headers
    def create_cloud_connector_with_http_info(cloud_connector_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: CloudConnectorsApi.create_cloud_connector ...'
      end
      # verify the required parameter 'cloud_connector_body' is set
      if @api_client.config.client_side_validation && cloud_connector_body.nil?
        fail ArgumentError, "Missing the required parameter 'cloud_connector_body' when calling CloudConnectorsApi.create_cloud_connector"
      end
      # resource path
      local_var_path = '/cloud_connectors'

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(cloud_connector_body) 

      # return_type
      return_type = opts[:return_type] || 'CloudConnector' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: CloudConnectorsApi#create_cloud_connector\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Destroys a specific cloud connector.
    # **API Key Scope**: cloud_connectors / destroy
    # @param cloud_connector_id [String] Numeric ID or name of cloud connector.
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def destroy_cloud_connector(cloud_connector_id, opts = {})
      destroy_cloud_connector_with_http_info(cloud_connector_id, opts)
      nil
    end

    # Destroys a specific cloud connector.
    # **API Key Scope**: cloud_connectors / destroy
    # @param cloud_connector_id [String] Numeric ID or name of cloud connector.
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
    def destroy_cloud_connector_with_http_info(cloud_connector_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: CloudConnectorsApi.destroy_cloud_connector ...'
      end
      # verify the required parameter 'cloud_connector_id' is set
      if @api_client.config.client_side_validation && cloud_connector_id.nil?
        fail ArgumentError, "Missing the required parameter 'cloud_connector_id' when calling CloudConnectorsApi.destroy_cloud_connector"
      end
      # resource path
      local_var_path = '/cloud_connectors/{cloud_connector_id}'.sub('{' + 'cloud_connector_id' + '}', CGI.escape(cloud_connector_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: CloudConnectorsApi#destroy_cloud_connector\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Lists all cloud connectors.
    # **API Key Scope**: cloud_connectors / index   Optional API Key Explicit Scope: cloud_connectors / get_secret_key
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :url Filter on url
    # @option opts [String] :url_proxy Filter on url proxy
    # @option opts [String] :provider Filter on provider
    # @option opts [String] :region Filter on region
    # @option opts [String] :access_key Filter on access key
    # @return [CloudConnectorCollection]
    def index_cloud_connectors(opts = {})
      data, _status_code, _headers = index_cloud_connectors_with_http_info(opts)
      data
    end

    # Lists all cloud connectors.
    # **API Key Scope**: cloud_connectors / index   Optional API Key Explicit Scope: cloud_connectors / get_secret_key
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :url Filter on url
    # @option opts [String] :url_proxy Filter on url proxy
    # @option opts [String] :provider Filter on provider
    # @option opts [String] :region Filter on region
    # @option opts [String] :access_key Filter on access key
    # @return [Array<(CloudConnectorCollection, Integer, Hash)>] CloudConnectorCollection data, response status code and response headers
    def index_cloud_connectors_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: CloudConnectorsApi.index_cloud_connectors ...'
      end
      # resource path
      local_var_path = '/cloud_connectors'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
      query_params[:'sort_by'] = @api_client.build_collection_param(opts[:'sort_by'], :pipe) if !opts[:'sort_by'].nil?
      query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
      query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
      query_params[:'url'] = opts[:'url'] if !opts[:'url'].nil?
      query_params[:'url_proxy'] = opts[:'url_proxy'] if !opts[:'url_proxy'].nil?
      query_params[:'provider'] = opts[:'provider'] if !opts[:'provider'].nil?
      query_params[:'region'] = opts[:'region'] if !opts[:'region'].nil?
      query_params[:'access_key'] = opts[:'access_key'] if !opts[:'access_key'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'CloudConnectorCollection' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: CloudConnectorsApi#index_cloud_connectors\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Displays a specific cloud connector.
    # **API Key Scope**: cloud_connectors / show   Optional API Key Explicit Scope: cloud_connectors / get_secret_key
    # @param cloud_connector_id [String] Numeric ID or name of cloud connector.
    # @param [Hash] opts the optional parameters
    # @return [CloudConnector]
    def show_cloud_connector(cloud_connector_id, opts = {})
      data, _status_code, _headers = show_cloud_connector_with_http_info(cloud_connector_id, opts)
      data
    end

    # Displays a specific cloud connector.
    # **API Key Scope**: cloud_connectors / show   Optional API Key Explicit Scope: cloud_connectors / get_secret_key
    # @param cloud_connector_id [String] Numeric ID or name of cloud connector.
    # @param [Hash] opts the optional parameters
    # @return [Array<(CloudConnector, Integer, Hash)>] CloudConnector data, response status code and response headers
    def show_cloud_connector_with_http_info(cloud_connector_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: CloudConnectorsApi.show_cloud_connector ...'
      end
      # verify the required parameter 'cloud_connector_id' is set
      if @api_client.config.client_side_validation && cloud_connector_id.nil?
        fail ArgumentError, "Missing the required parameter 'cloud_connector_id' when calling CloudConnectorsApi.show_cloud_connector"
      end
      # resource path
      local_var_path = '/cloud_connectors/{cloud_connector_id}'.sub('{' + 'cloud_connector_id' + '}', CGI.escape(cloud_connector_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'CloudConnector' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: CloudConnectorsApi#show_cloud_connector\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Test an unsaved cloud connector.
    # **API Key Scope**: cloud_connectors / test
    # @param cloud_connector_body [CloudConnector] 
    # @param [Hash] opts the optional parameters
    # @return [ActiveJobStatus]
    def test_cloud_connector(cloud_connector_body, opts = {})
      data, _status_code, _headers = test_cloud_connector_with_http_info(cloud_connector_body, opts)
      data
    end

    # Test an unsaved cloud connector.
    # **API Key Scope**: cloud_connectors / test
    # @param cloud_connector_body [CloudConnector] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(ActiveJobStatus, Integer, Hash)>] ActiveJobStatus data, response status code and response headers
    def test_cloud_connector_with_http_info(cloud_connector_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: CloudConnectorsApi.test_cloud_connector ...'
      end
      # verify the required parameter 'cloud_connector_body' is set
      if @api_client.config.client_side_validation && cloud_connector_body.nil?
        fail ArgumentError, "Missing the required parameter 'cloud_connector_body' when calling CloudConnectorsApi.test_cloud_connector"
      end
      # resource path
      local_var_path = '/cloud_connectors/-/test'

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json', 'queued', 'working', 'failed'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(cloud_connector_body) 

      # return_type
      return_type = opts[:return_type] || 'ActiveJobStatus' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: CloudConnectorsApi#test_cloud_connector\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Check result of cloud connector test job.
    # **API Key Scope**: cloud_connectors / test
    # @param job_id [String] ID of active job
    # @param [Hash] opts the optional parameters
    # @return [CloudBucketSimpleCollection]
    def test_result_cloud_connector(job_id, opts = {})
      data, _status_code, _headers = test_result_cloud_connector_with_http_info(job_id, opts)
      data
    end

    # Check result of cloud connector test job.
    # **API Key Scope**: cloud_connectors / test
    # @param job_id [String] ID of active job
    # @param [Hash] opts the optional parameters
    # @return [Array<(CloudBucketSimpleCollection, Integer, Hash)>] CloudBucketSimpleCollection data, response status code and response headers
    def test_result_cloud_connector_with_http_info(job_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: CloudConnectorsApi.test_result_cloud_connector ...'
      end
      # verify the required parameter 'job_id' is set
      if @api_client.config.client_side_validation && job_id.nil?
        fail ArgumentError, "Missing the required parameter 'job_id' when calling CloudConnectorsApi.test_result_cloud_connector"
      end
      # resource path
      local_var_path = '/cloud_connectors/-/test'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'job_id'] = job_id

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json', 'queued', 'working', 'failed', ])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'CloudBucketSimpleCollection' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: CloudConnectorsApi#test_result_cloud_connector\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Updates a specific cloud connector.
    # **API Key Scope**: cloud_connectors / update
    # @param cloud_connector_id [String] Numeric ID or name of cloud connector.
    # @param cloud_connector_body [CloudConnector] 
    # @param [Hash] opts the optional parameters
    # @return [CloudConnector]
    def update_cloud_connector(cloud_connector_id, cloud_connector_body, opts = {})
      data, _status_code, _headers = update_cloud_connector_with_http_info(cloud_connector_id, cloud_connector_body, opts)
      data
    end

    # Updates a specific cloud connector.
    # **API Key Scope**: cloud_connectors / update
    # @param cloud_connector_id [String] Numeric ID or name of cloud connector.
    # @param cloud_connector_body [CloudConnector] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(CloudConnector, Integer, Hash)>] CloudConnector data, response status code and response headers
    def update_cloud_connector_with_http_info(cloud_connector_id, cloud_connector_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: CloudConnectorsApi.update_cloud_connector ...'
      end
      # verify the required parameter 'cloud_connector_id' is set
      if @api_client.config.client_side_validation && cloud_connector_id.nil?
        fail ArgumentError, "Missing the required parameter 'cloud_connector_id' when calling CloudConnectorsApi.update_cloud_connector"
      end
      # verify the required parameter 'cloud_connector_body' is set
      if @api_client.config.client_side_validation && cloud_connector_body.nil?
        fail ArgumentError, "Missing the required parameter 'cloud_connector_body' when calling CloudConnectorsApi.update_cloud_connector"
      end
      # resource path
      local_var_path = '/cloud_connectors/{cloud_connector_id}'.sub('{' + 'cloud_connector_id' + '}', CGI.escape(cloud_connector_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(cloud_connector_body) 

      # return_type
      return_type = opts[:return_type] || 'CloudConnector' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: CloudConnectorsApi#update_cloud_connector\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end
  end
end
