=begin
#Nodeum API

#The Nodeum API makes it easy to tap into the digital data mesh that runs across your organisation. Make requests to our API endpoints and we’ll give you everything you need to interconnect your business workflows with your storage.  All production API requests are made to:  http://nodeumhostname/api/  The current production version of the API is v1.   **REST** The Nodeum API is a RESTful API. This means that the API is designed to allow you to get, create, update, & delete objects with the HTTP verbs GET, POST, PUT, PATCH, & DELETE.  **JSON** The Nodeum API speaks exclusively in JSON. This means that you should always set the Content-Type header to application/json to ensure that your requests are properly accepted and processed by the API.  **Authentication** All API calls require user-password authentication.   **Cross-Origin Resource Sharing** The Nodeum API supports CORS for communicating from Javascript for these endpoints. You will need to specify an Origin URI when creating your application to allow for CORS to be whitelisted for your domain.   **Pagination** Some endpoints such as File Listing return a potentially lengthy array of objects. In order to keep the response sizes manageable the API will take advantage of pagination. Pagination is a mechanism for returning a subset of the results for a request and allowing for subsequent requests to “page” through the rest of the results until the end is reached. Paginated endpoints follow a standard interface that accepts two query parameters, limit and offset, and return a payload that follows a standard form. These parameters names and their behavior are borrowed from SQL LIMIT and OFFSET keywords.  **Versioning** The Nodeum API is constantly being worked on to add features, make improvements, and fix bugs. This means that you should expect changes to be introduced and documented.   However, there are some changes or additions that are considered backwards-compatible and your applications should be flexible enough to handle them. These include:  - Adding new endpoints to the API - Adding new attributes to the response of an existing endpoint - Changing the order of attributes of responses (JSON by definition is an object of unordered key/value pairs)  **Filter parameters** When browsing a list of items, multiple filter parameters may be applied. Some operators can be added to the value as a prefix:  - `=` value is equal. Default operator, may be omitted  - `!=` value is different  - `>` greater than  - `>=` greater than or equal  - `<` lower than  - `>=` lower than or equal  - `><` included in list, items should be separated by `|`  - `!><` not included in list, items should be separated by `|`  - `~` pattern matching, may include `%` (any characters) and `_` (one character)  - `!~` pattern not matching, may include `%` (any characters) and `_` (one character)  

The version of the OpenAPI document: 2.1.0
Contact: info@nodeum.io
Generated by: https://openapi-generator.tech
OpenAPI Generator version: 4.3.0

=end

require 'cgi'

module Nodeum
  class ContainersApi
    attr_accessor :api_client

    def initialize(api_client = ApiClient.default)
      @api_client = api_client
    end
    # Creates a new container.
    # It **does not** yet create the file structure and configure the samba connection. Use API v1 instead.  **API Key Scope**: containers / create
    # @param container_body [Container] 
    # @param [Hash] opts the optional parameters
    # @return [Container]
    def create_container(container_body, opts = {})
      data, _status_code, _headers = create_container_with_http_info(container_body, opts)
      data
    end

    # Creates a new container.
    # It **does not** yet create the file structure and configure the samba connection. Use API v1 instead.  **API Key Scope**: containers / create
    # @param container_body [Container] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(Container, Integer, Hash)>] Container data, response status code and response headers
    def create_container_with_http_info(container_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.create_container ...'
      end
      # verify the required parameter 'container_body' is set
      if @api_client.config.client_side_validation && container_body.nil?
        fail ArgumentError, "Missing the required parameter 'container_body' when calling ContainersApi.create_container"
      end
      # resource path
      local_var_path = '/containers'

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(container_body) 

      # return_type
      return_type = opts[:return_type] || 'Container' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#create_container\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Creates a new privilege on the container.
    # **API Key Scope**: container_privileges / create
    # @param container_id [String] Numeric ID or name of container.
    # @param container_privilege_body [ContainerPrivilege] 
    # @param [Hash] opts the optional parameters
    # @return [ContainerPrivilege]
    def create_container_privilege(container_id, container_privilege_body, opts = {})
      data, _status_code, _headers = create_container_privilege_with_http_info(container_id, container_privilege_body, opts)
      data
    end

    # Creates a new privilege on the container.
    # **API Key Scope**: container_privileges / create
    # @param container_id [String] Numeric ID or name of container.
    # @param container_privilege_body [ContainerPrivilege] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(ContainerPrivilege, Integer, Hash)>] ContainerPrivilege data, response status code and response headers
    def create_container_privilege_with_http_info(container_id, container_privilege_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.create_container_privilege ...'
      end
      # verify the required parameter 'container_id' is set
      if @api_client.config.client_side_validation && container_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_id' when calling ContainersApi.create_container_privilege"
      end
      # verify the required parameter 'container_privilege_body' is set
      if @api_client.config.client_side_validation && container_privilege_body.nil?
        fail ArgumentError, "Missing the required parameter 'container_privilege_body' when calling ContainersApi.create_container_privilege"
      end
      # resource path
      local_var_path = '/containers/{container_id}/container_privileges'.sub('{' + 'container_id' + '}', CGI.escape(container_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(container_privilege_body) 

      # return_type
      return_type = opts[:return_type] || 'ContainerPrivilege' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#create_container_privilege\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Destroys a specific container.
    # **API Key Scope**: containers / destroy
    # @param container_id [String] Numeric ID or name of container.
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def destroy_container(container_id, opts = {})
      destroy_container_with_http_info(container_id, opts)
      nil
    end

    # Destroys a specific container.
    # **API Key Scope**: containers / destroy
    # @param container_id [String] Numeric ID or name of container.
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
    def destroy_container_with_http_info(container_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.destroy_container ...'
      end
      # verify the required parameter 'container_id' is set
      if @api_client.config.client_side_validation && container_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_id' when calling ContainersApi.destroy_container"
      end
      # resource path
      local_var_path = '/containers/{container_id}'.sub('{' + 'container_id' + '}', CGI.escape(container_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#destroy_container\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Destroys a specific privilege.
    # **API Key Scope**: container_privileges / destroy
    # @param container_id [String] Numeric ID or name of container.
    # @param container_privilege_id [Integer] Numeric ID of container privilege.
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def destroy_container_privilege(container_id, container_privilege_id, opts = {})
      destroy_container_privilege_with_http_info(container_id, container_privilege_id, opts)
      nil
    end

    # Destroys a specific privilege.
    # **API Key Scope**: container_privileges / destroy
    # @param container_id [String] Numeric ID or name of container.
    # @param container_privilege_id [Integer] Numeric ID of container privilege.
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
    def destroy_container_privilege_with_http_info(container_id, container_privilege_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.destroy_container_privilege ...'
      end
      # verify the required parameter 'container_id' is set
      if @api_client.config.client_side_validation && container_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_id' when calling ContainersApi.destroy_container_privilege"
      end
      # verify the required parameter 'container_privilege_id' is set
      if @api_client.config.client_side_validation && container_privilege_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_privilege_id' when calling ContainersApi.destroy_container_privilege"
      end
      # resource path
      local_var_path = '/containers/{container_id}/container_privileges/{container_privilege_id}'.sub('{' + 'container_id' + '}', CGI.escape(container_id.to_s)).sub('{' + 'container_privilege_id' + '}', CGI.escape(container_privilege_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#destroy_container_privilege\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Lists all privilege on the container.
    # **API Key Scope**: container_privileges / index
    # @param container_id [String] Numeric ID or name of container.
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :privilege Filter on privilege
    # @option opts [String] :type Filter on type
    # @return [ContainerPrivilegeCollection]
    def index_container_privileges(container_id, opts = {})
      data, _status_code, _headers = index_container_privileges_with_http_info(container_id, opts)
      data
    end

    # Lists all privilege on the container.
    # **API Key Scope**: container_privileges / index
    # @param container_id [String] Numeric ID or name of container.
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :privilege Filter on privilege
    # @option opts [String] :type Filter on type
    # @return [Array<(ContainerPrivilegeCollection, Integer, Hash)>] ContainerPrivilegeCollection data, response status code and response headers
    def index_container_privileges_with_http_info(container_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.index_container_privileges ...'
      end
      # verify the required parameter 'container_id' is set
      if @api_client.config.client_side_validation && container_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_id' when calling ContainersApi.index_container_privileges"
      end
      # resource path
      local_var_path = '/containers/{container_id}/container_privileges'.sub('{' + 'container_id' + '}', CGI.escape(container_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
      query_params[:'sort_by'] = @api_client.build_collection_param(opts[:'sort_by'], :pipe) if !opts[:'sort_by'].nil?
      query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
      query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
      query_params[:'privilege'] = opts[:'privilege'] if !opts[:'privilege'].nil?
      query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'ContainerPrivilegeCollection' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#index_container_privileges\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Lists all containers.
    # **API Key Scope**: containers / index
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :comment Filter on comment
    # @option opts [String] :quota_total_size Filter on quota total size
    # @option opts [String] :quota_on_cache Filter on quota on cache
    # @option opts [String] :stat_total_files Filter on stat total files
    # @option opts [String] :stat_total_size Filter on stat total size
    # @option opts [String] :stat_size_on_cache Filter on stat size on cache
    # @option opts [String] :guest_right Filter on guest right
    # @option opts [String] :last_update Filter on last update
    # @return [ContainerCollection]
    def index_containers(opts = {})
      data, _status_code, _headers = index_containers_with_http_info(opts)
      data
    end

    # Lists all containers.
    # **API Key Scope**: containers / index
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :comment Filter on comment
    # @option opts [String] :quota_total_size Filter on quota total size
    # @option opts [String] :quota_on_cache Filter on quota on cache
    # @option opts [String] :stat_total_files Filter on stat total files
    # @option opts [String] :stat_total_size Filter on stat total size
    # @option opts [String] :stat_size_on_cache Filter on stat size on cache
    # @option opts [String] :guest_right Filter on guest right
    # @option opts [String] :last_update Filter on last update
    # @return [Array<(ContainerCollection, Integer, Hash)>] ContainerCollection data, response status code and response headers
    def index_containers_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.index_containers ...'
      end
      # resource path
      local_var_path = '/containers'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
      query_params[:'sort_by'] = @api_client.build_collection_param(opts[:'sort_by'], :pipe) if !opts[:'sort_by'].nil?
      query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
      query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
      query_params[:'comment'] = opts[:'comment'] if !opts[:'comment'].nil?
      query_params[:'quota_total_size'] = opts[:'quota_total_size'] if !opts[:'quota_total_size'].nil?
      query_params[:'quota_on_cache'] = opts[:'quota_on_cache'] if !opts[:'quota_on_cache'].nil?
      query_params[:'stat_total_files'] = opts[:'stat_total_files'] if !opts[:'stat_total_files'].nil?
      query_params[:'stat_total_size'] = opts[:'stat_total_size'] if !opts[:'stat_total_size'].nil?
      query_params[:'stat_size_on_cache'] = opts[:'stat_size_on_cache'] if !opts[:'stat_size_on_cache'].nil?
      query_params[:'guest_right'] = opts[:'guest_right'] if !opts[:'guest_right'].nil?
      query_params[:'last_update'] = opts[:'last_update'] if !opts[:'last_update'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'ContainerCollection' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#index_containers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Displays a specific container.
    # **API Key Scope**: containers / show
    # @param container_id [String] Numeric ID or name of container.
    # @param [Hash] opts the optional parameters
    # @return [Container]
    def show_container(container_id, opts = {})
      data, _status_code, _headers = show_container_with_http_info(container_id, opts)
      data
    end

    # Displays a specific container.
    # **API Key Scope**: containers / show
    # @param container_id [String] Numeric ID or name of container.
    # @param [Hash] opts the optional parameters
    # @return [Array<(Container, Integer, Hash)>] Container data, response status code and response headers
    def show_container_with_http_info(container_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.show_container ...'
      end
      # verify the required parameter 'container_id' is set
      if @api_client.config.client_side_validation && container_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_id' when calling ContainersApi.show_container"
      end
      # resource path
      local_var_path = '/containers/{container_id}'.sub('{' + 'container_id' + '}', CGI.escape(container_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'Container' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#show_container\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Displays a specific privilege.
    # **API Key Scope**: container_privileges / show
    # @param container_id [String] Numeric ID or name of container.
    # @param container_privilege_id [Integer] Numeric ID of container privilege.
    # @param [Hash] opts the optional parameters
    # @return [ContainerPrivilege]
    def show_container_privilege(container_id, container_privilege_id, opts = {})
      data, _status_code, _headers = show_container_privilege_with_http_info(container_id, container_privilege_id, opts)
      data
    end

    # Displays a specific privilege.
    # **API Key Scope**: container_privileges / show
    # @param container_id [String] Numeric ID or name of container.
    # @param container_privilege_id [Integer] Numeric ID of container privilege.
    # @param [Hash] opts the optional parameters
    # @return [Array<(ContainerPrivilege, Integer, Hash)>] ContainerPrivilege data, response status code and response headers
    def show_container_privilege_with_http_info(container_id, container_privilege_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.show_container_privilege ...'
      end
      # verify the required parameter 'container_id' is set
      if @api_client.config.client_side_validation && container_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_id' when calling ContainersApi.show_container_privilege"
      end
      # verify the required parameter 'container_privilege_id' is set
      if @api_client.config.client_side_validation && container_privilege_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_privilege_id' when calling ContainersApi.show_container_privilege"
      end
      # resource path
      local_var_path = '/containers/{container_id}/container_privileges/{container_privilege_id}'.sub('{' + 'container_id' + '}', CGI.escape(container_id.to_s)).sub('{' + 'container_privilege_id' + '}', CGI.escape(container_privilege_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'ContainerPrivilege' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#show_container_privilege\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Updates a specific container.
    # It **does not** yet create the file structure and configure the samba connection. Use API v1 instead.  **API Key Scope**: containers / update
    # @param container_id [String] Numeric ID or name of container.
    # @param container_body [Container] 
    # @param [Hash] opts the optional parameters
    # @return [Container]
    def update_container(container_id, container_body, opts = {})
      data, _status_code, _headers = update_container_with_http_info(container_id, container_body, opts)
      data
    end

    # Updates a specific container.
    # It **does not** yet create the file structure and configure the samba connection. Use API v1 instead.  **API Key Scope**: containers / update
    # @param container_id [String] Numeric ID or name of container.
    # @param container_body [Container] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(Container, Integer, Hash)>] Container data, response status code and response headers
    def update_container_with_http_info(container_id, container_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.update_container ...'
      end
      # verify the required parameter 'container_id' is set
      if @api_client.config.client_side_validation && container_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_id' when calling ContainersApi.update_container"
      end
      # verify the required parameter 'container_body' is set
      if @api_client.config.client_side_validation && container_body.nil?
        fail ArgumentError, "Missing the required parameter 'container_body' when calling ContainersApi.update_container"
      end
      # resource path
      local_var_path = '/containers/{container_id}'.sub('{' + 'container_id' + '}', CGI.escape(container_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(container_body) 

      # return_type
      return_type = opts[:return_type] || 'Container' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#update_container\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Updates a specific privilege.
    # **API Key Scope**: container_privileges / update
    # @param container_id [String] Numeric ID or name of container.
    # @param container_privilege_id [Integer] Numeric ID of container privilege.
    # @param container_privilege_body [ContainerPrivilege] 
    # @param [Hash] opts the optional parameters
    # @return [ContainerPrivilege]
    def update_container_privilege(container_id, container_privilege_id, container_privilege_body, opts = {})
      data, _status_code, _headers = update_container_privilege_with_http_info(container_id, container_privilege_id, container_privilege_body, opts)
      data
    end

    # Updates a specific privilege.
    # **API Key Scope**: container_privileges / update
    # @param container_id [String] Numeric ID or name of container.
    # @param container_privilege_id [Integer] Numeric ID of container privilege.
    # @param container_privilege_body [ContainerPrivilege] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(ContainerPrivilege, Integer, Hash)>] ContainerPrivilege data, response status code and response headers
    def update_container_privilege_with_http_info(container_id, container_privilege_id, container_privilege_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ContainersApi.update_container_privilege ...'
      end
      # verify the required parameter 'container_id' is set
      if @api_client.config.client_side_validation && container_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_id' when calling ContainersApi.update_container_privilege"
      end
      # verify the required parameter 'container_privilege_id' is set
      if @api_client.config.client_side_validation && container_privilege_id.nil?
        fail ArgumentError, "Missing the required parameter 'container_privilege_id' when calling ContainersApi.update_container_privilege"
      end
      # verify the required parameter 'container_privilege_body' is set
      if @api_client.config.client_side_validation && container_privilege_body.nil?
        fail ArgumentError, "Missing the required parameter 'container_privilege_body' when calling ContainersApi.update_container_privilege"
      end
      # resource path
      local_var_path = '/containers/{container_id}/container_privileges/{container_privilege_id}'.sub('{' + 'container_id' + '}', CGI.escape(container_id.to_s)).sub('{' + 'container_privilege_id' + '}', CGI.escape(container_privilege_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(container_privilege_body) 

      # return_type
      return_type = opts[:return_type] || 'ContainerPrivilege' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ContainersApi#update_container_privilege\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end
  end
end
