=begin
#Nodeum API

#The Nodeum API makes it easy to tap into the digital data mesh that runs across your organisation. Make requests to our API endpoints and we’ll give you everything you need to interconnect your business workflows with your storage.  All production API requests are made to:  http://nodeumhostname/api/  The current production version of the API is v1.   **REST** The Nodeum API is a RESTful API. This means that the API is designed to allow you to get, create, update, & delete objects with the HTTP verbs GET, POST, PUT, PATCH, & DELETE.  **JSON** The Nodeum API speaks exclusively in JSON. This means that you should always set the Content-Type header to application/json to ensure that your requests are properly accepted and processed by the API.  **Authentication** All API calls require user-password authentication.   **Cross-Origin Resource Sharing** The Nodeum API supports CORS for communicating from Javascript for these endpoints. You will need to specify an Origin URI when creating your application to allow for CORS to be whitelisted for your domain.   **Pagination** Some endpoints such as File Listing return a potentially lengthy array of objects. In order to keep the response sizes manageable the API will take advantage of pagination. Pagination is a mechanism for returning a subset of the results for a request and allowing for subsequent requests to “page” through the rest of the results until the end is reached. Paginated endpoints follow a standard interface that accepts two query parameters, limit and offset, and return a payload that follows a standard form. These parameters names and their behavior are borrowed from SQL LIMIT and OFFSET keywords.  **Versioning** The Nodeum API is constantly being worked on to add features, make improvements, and fix bugs. This means that you should expect changes to be introduced and documented.   However, there are some changes or additions that are considered backwards-compatible and your applications should be flexible enough to handle them. These include:  - Adding new endpoints to the API - Adding new attributes to the response of an existing endpoint - Changing the order of attributes of responses (JSON by definition is an object of unordered key/value pairs)  **Filter parameters** When browsing a list of items, multiple filter parameters may be applied. Some operators can be added to the value as a prefix:  - `=` value is equal. Default operator, may be omitted  - `!=` value is different  - `>` greater than  - `>=` greater than or equal  - `<` lower than  - `>=` lower than or equal  - `><` included in list, items should be separated by `|`  - `!><` not included in list, items should be separated by `|`  - `~` pattern matching, may include `%` (any characters) and `_` (one character)  - `!~` pattern not matching, may include `%` (any characters) and `_` (one character)  

The version of the OpenAPI document: 2.1.0
Contact: info@nodeum.io
Generated by: https://openapi-generator.tech
OpenAPI Generator version: 4.3.0

=end

require 'cgi'

module Nodeum
  class NasSharesApi
    attr_accessor :api_client

    def initialize(api_client = ApiClient.default)
      @api_client = api_client
    end
    # Creates a new NAS share.
    # **API Key Scope**: nas_shares / create
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [NasShare]
    def create_nas_share_by_nas(nas_id, nas_share_body, opts = {})
      data, _status_code, _headers = create_nas_share_by_nas_with_http_info(nas_id, nas_share_body, opts)
      data
    end

    # Creates a new NAS share.
    # **API Key Scope**: nas_shares / create
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(NasShare, Integer, Hash)>] NasShare data, response status code and response headers
    def create_nas_share_by_nas_with_http_info(nas_id, nas_share_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.create_nas_share_by_nas ...'
      end
      # verify the required parameter 'nas_id' is set
      if @api_client.config.client_side_validation && nas_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_id' when calling NasSharesApi.create_nas_share_by_nas"
      end
      # verify the required parameter 'nas_share_body' is set
      if @api_client.config.client_side_validation && nas_share_body.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_body' when calling NasSharesApi.create_nas_share_by_nas"
      end
      # resource path
      local_var_path = '/nas/{nas_id}/nas_shares'.sub('{' + 'nas_id' + '}', CGI.escape(nas_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(nas_share_body) 

      # return_type
      return_type = opts[:return_type] || 'NasShare' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#create_nas_share_by_nas\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Destroys a specific NAS share.
    # **API Key Scope**: nas_shares / destroy
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def destroy_nas_share(nas_share_id, opts = {})
      destroy_nas_share_with_http_info(nas_share_id, opts)
      nil
    end

    # Destroys a specific NAS share.
    # **API Key Scope**: nas_shares / destroy
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
    def destroy_nas_share_with_http_info(nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.destroy_nas_share ...'
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.destroy_nas_share"
      end
      # resource path
      local_var_path = '/nas_shares/{nas_share_id}'.sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#destroy_nas_share\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Destroys a specific NAS share.
    # **API Key Scope**: nas_shares / destroy
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def destroy_nas_share_by_nas(nas_id, nas_share_id, opts = {})
      destroy_nas_share_by_nas_with_http_info(nas_id, nas_share_id, opts)
      nil
    end

    # Destroys a specific NAS share.
    # **API Key Scope**: nas_shares / destroy
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
    def destroy_nas_share_by_nas_with_http_info(nas_id, nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.destroy_nas_share_by_nas ...'
      end
      # verify the required parameter 'nas_id' is set
      if @api_client.config.client_side_validation && nas_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_id' when calling NasSharesApi.destroy_nas_share_by_nas"
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.destroy_nas_share_by_nas"
      end
      # resource path
      local_var_path = '/nas/{nas_id}/nas_shares/{nas_share_id}'.sub('{' + 'nas_id' + '}', CGI.escape(nas_id.to_s)).sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#destroy_nas_share_by_nas\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Destroys a specific NAS share.
    # **API Key Scope**: nas_shares / destroy
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def destroy_nas_share_by_pool(pool_id, nas_share_id, opts = {})
      destroy_nas_share_by_pool_with_http_info(pool_id, nas_share_id, opts)
      nil
    end

    # Destroys a specific NAS share.
    # **API Key Scope**: nas_shares / destroy
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
    def destroy_nas_share_by_pool_with_http_info(pool_id, nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.destroy_nas_share_by_pool ...'
      end
      # verify the required parameter 'pool_id' is set
      if @api_client.config.client_side_validation && pool_id.nil?
        fail ArgumentError, "Missing the required parameter 'pool_id' when calling NasSharesApi.destroy_nas_share_by_pool"
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.destroy_nas_share_by_pool"
      end
      # resource path
      local_var_path = '/pools/{pool_id}/nas_shares/{nas_share_id}'.sub('{' + 'pool_id' + '}', CGI.escape(pool_id.to_s)).sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#destroy_nas_share_by_pool\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Lists all NAS shares.
    # **API Key Scope**: nas_shares / index   Optional API Key Explicit Scope: nas_shares / get_password
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :path Filter on path
    # @option opts [String] :options Filter on options
    # @option opts [String] :username Filter on username
    # @option opts [String] :nas_id Filter on NAS id
    # @option opts [String] :pool_id Filter on a pool id
    # @return [NasShareCollection]
    def index_nas_shares(opts = {})
      data, _status_code, _headers = index_nas_shares_with_http_info(opts)
      data
    end

    # Lists all NAS shares.
    # **API Key Scope**: nas_shares / index   Optional API Key Explicit Scope: nas_shares / get_password
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :path Filter on path
    # @option opts [String] :options Filter on options
    # @option opts [String] :username Filter on username
    # @option opts [String] :nas_id Filter on NAS id
    # @option opts [String] :pool_id Filter on a pool id
    # @return [Array<(NasShareCollection, Integer, Hash)>] NasShareCollection data, response status code and response headers
    def index_nas_shares_with_http_info(opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.index_nas_shares ...'
      end
      # resource path
      local_var_path = '/nas_shares'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
      query_params[:'sort_by'] = @api_client.build_collection_param(opts[:'sort_by'], :pipe) if !opts[:'sort_by'].nil?
      query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
      query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
      query_params[:'path'] = opts[:'path'] if !opts[:'path'].nil?
      query_params[:'options'] = opts[:'options'] if !opts[:'options'].nil?
      query_params[:'username'] = opts[:'username'] if !opts[:'username'].nil?
      query_params[:'nas_id'] = opts[:'nas_id'] if !opts[:'nas_id'].nil?
      query_params[:'pool_id'] = opts[:'pool_id'] if !opts[:'pool_id'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'NasShareCollection' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#index_nas_shares\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Lists all NAS shares.
    # **API Key Scope**: nas_shares / index   Optional API Key Explicit Scope: nas_shares / get_password
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :path Filter on path
    # @option opts [String] :options Filter on options
    # @option opts [String] :username Filter on username
    # @option opts [String] :pool_id Filter on a pool id
    # @return [NasShareCollection]
    def index_nas_shares_by_nas(nas_id, opts = {})
      data, _status_code, _headers = index_nas_shares_by_nas_with_http_info(nas_id, opts)
      data
    end

    # Lists all NAS shares.
    # **API Key Scope**: nas_shares / index   Optional API Key Explicit Scope: nas_shares / get_password
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :path Filter on path
    # @option opts [String] :options Filter on options
    # @option opts [String] :username Filter on username
    # @option opts [String] :pool_id Filter on a pool id
    # @return [Array<(NasShareCollection, Integer, Hash)>] NasShareCollection data, response status code and response headers
    def index_nas_shares_by_nas_with_http_info(nas_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.index_nas_shares_by_nas ...'
      end
      # verify the required parameter 'nas_id' is set
      if @api_client.config.client_side_validation && nas_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_id' when calling NasSharesApi.index_nas_shares_by_nas"
      end
      # resource path
      local_var_path = '/nas/{nas_id}/nas_shares'.sub('{' + 'nas_id' + '}', CGI.escape(nas_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
      query_params[:'sort_by'] = @api_client.build_collection_param(opts[:'sort_by'], :pipe) if !opts[:'sort_by'].nil?
      query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
      query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
      query_params[:'path'] = opts[:'path'] if !opts[:'path'].nil?
      query_params[:'options'] = opts[:'options'] if !opts[:'options'].nil?
      query_params[:'username'] = opts[:'username'] if !opts[:'username'].nil?
      query_params[:'pool_id'] = opts[:'pool_id'] if !opts[:'pool_id'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'NasShareCollection' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#index_nas_shares_by_nas\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Lists all NAS shares from pool.
    # **API Key Scope**: nas_shares / index   Optional API Key Explicit Scope: nas_shares / get_password
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :path Filter on path
    # @option opts [String] :options Filter on options
    # @option opts [String] :username Filter on username
    # @option opts [String] :nas_id Filter on NAS id
    # @return [NasShareCollection]
    def index_nas_shares_by_pool(pool_id, opts = {})
      data, _status_code, _headers = index_nas_shares_by_pool_with_http_info(pool_id, opts)
      data
    end

    # Lists all NAS shares from pool.
    # **API Key Scope**: nas_shares / index   Optional API Key Explicit Scope: nas_shares / get_password
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :name Filter on name
    # @option opts [String] :path Filter on path
    # @option opts [String] :options Filter on options
    # @option opts [String] :username Filter on username
    # @option opts [String] :nas_id Filter on NAS id
    # @return [Array<(NasShareCollection, Integer, Hash)>] NasShareCollection data, response status code and response headers
    def index_nas_shares_by_pool_with_http_info(pool_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.index_nas_shares_by_pool ...'
      end
      # verify the required parameter 'pool_id' is set
      if @api_client.config.client_side_validation && pool_id.nil?
        fail ArgumentError, "Missing the required parameter 'pool_id' when calling NasSharesApi.index_nas_shares_by_pool"
      end
      # resource path
      local_var_path = '/pools/{pool_id}/nas_shares'.sub('{' + 'pool_id' + '}', CGI.escape(pool_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
      query_params[:'sort_by'] = @api_client.build_collection_param(opts[:'sort_by'], :pipe) if !opts[:'sort_by'].nil?
      query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
      query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
      query_params[:'path'] = opts[:'path'] if !opts[:'path'].nil?
      query_params[:'options'] = opts[:'options'] if !opts[:'options'].nil?
      query_params[:'username'] = opts[:'username'] if !opts[:'username'].nil?
      query_params[:'nas_id'] = opts[:'nas_id'] if !opts[:'nas_id'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'NasShareCollection' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#index_nas_shares_by_pool\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Get mount status of NAS Share.
    # **API Key Scope**: nas_shares / mount_status
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [MountStatus]
    def mount_status_nas_share(nas_share_id, opts = {})
      data, _status_code, _headers = mount_status_nas_share_with_http_info(nas_share_id, opts)
      data
    end

    # Get mount status of NAS Share.
    # **API Key Scope**: nas_shares / mount_status
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(MountStatus, Integer, Hash)>] MountStatus data, response status code and response headers
    def mount_status_nas_share_with_http_info(nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.mount_status_nas_share ...'
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.mount_status_nas_share"
      end
      # resource path
      local_var_path = '/nas_shares/{nas_share_id}/mount'.sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'MountStatus' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#mount_status_nas_share\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Get mount status of NAS Share.
    # **API Key Scope**: nas_shares / mount_status
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [MountStatus]
    def mount_status_nas_share_by_nas(nas_id, nas_share_id, opts = {})
      data, _status_code, _headers = mount_status_nas_share_by_nas_with_http_info(nas_id, nas_share_id, opts)
      data
    end

    # Get mount status of NAS Share.
    # **API Key Scope**: nas_shares / mount_status
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(MountStatus, Integer, Hash)>] MountStatus data, response status code and response headers
    def mount_status_nas_share_by_nas_with_http_info(nas_id, nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.mount_status_nas_share_by_nas ...'
      end
      # verify the required parameter 'nas_id' is set
      if @api_client.config.client_side_validation && nas_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_id' when calling NasSharesApi.mount_status_nas_share_by_nas"
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.mount_status_nas_share_by_nas"
      end
      # resource path
      local_var_path = '/nas/{nas_id}/nas_shares/{nas_share_id}/mount'.sub('{' + 'nas_id' + '}', CGI.escape(nas_id.to_s)).sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'MountStatus' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#mount_status_nas_share_by_nas\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Get mount status of NAS Share.
    # **API Key Scope**: nas_shares / mount_status
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [MountStatus]
    def mount_status_nas_share_by_pool(pool_id, nas_share_id, opts = {})
      data, _status_code, _headers = mount_status_nas_share_by_pool_with_http_info(pool_id, nas_share_id, opts)
      data
    end

    # Get mount status of NAS Share.
    # **API Key Scope**: nas_shares / mount_status
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(MountStatus, Integer, Hash)>] MountStatus data, response status code and response headers
    def mount_status_nas_share_by_pool_with_http_info(pool_id, nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.mount_status_nas_share_by_pool ...'
      end
      # verify the required parameter 'pool_id' is set
      if @api_client.config.client_side_validation && pool_id.nil?
        fail ArgumentError, "Missing the required parameter 'pool_id' when calling NasSharesApi.mount_status_nas_share_by_pool"
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.mount_status_nas_share_by_pool"
      end
      # resource path
      local_var_path = '/pools/{pool_id}/nas_shares/{nas_share_id}/mount'.sub('{' + 'pool_id' + '}', CGI.escape(pool_id.to_s)).sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'MountStatus' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#mount_status_nas_share_by_pool\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Displays a specific NAS share.
    # **API Key Scope**: nas_shares / show   Optional API Key Explicit Scope: nas_shares / get_password
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [NasShare]
    def show_nas_share(nas_share_id, opts = {})
      data, _status_code, _headers = show_nas_share_with_http_info(nas_share_id, opts)
      data
    end

    # Displays a specific NAS share.
    # **API Key Scope**: nas_shares / show   Optional API Key Explicit Scope: nas_shares / get_password
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(NasShare, Integer, Hash)>] NasShare data, response status code and response headers
    def show_nas_share_with_http_info(nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.show_nas_share ...'
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.show_nas_share"
      end
      # resource path
      local_var_path = '/nas_shares/{nas_share_id}'.sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'NasShare' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#show_nas_share\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Displays a specific NAS share.
    # **API Key Scope**: nas_shares / show   Optional API Key Explicit Scope: nas_shares / get_password
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [NasShare]
    def show_nas_share_by_nas(nas_id, nas_share_id, opts = {})
      data, _status_code, _headers = show_nas_share_by_nas_with_http_info(nas_id, nas_share_id, opts)
      data
    end

    # Displays a specific NAS share.
    # **API Key Scope**: nas_shares / show   Optional API Key Explicit Scope: nas_shares / get_password
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(NasShare, Integer, Hash)>] NasShare data, response status code and response headers
    def show_nas_share_by_nas_with_http_info(nas_id, nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.show_nas_share_by_nas ...'
      end
      # verify the required parameter 'nas_id' is set
      if @api_client.config.client_side_validation && nas_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_id' when calling NasSharesApi.show_nas_share_by_nas"
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.show_nas_share_by_nas"
      end
      # resource path
      local_var_path = '/nas/{nas_id}/nas_shares/{nas_share_id}'.sub('{' + 'nas_id' + '}', CGI.escape(nas_id.to_s)).sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'NasShare' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#show_nas_share_by_nas\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Displays a specific NAS share.
    # **API Key Scope**: nas_shares / show   Optional API Key Explicit Scope: nas_shares / get_password
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [NasShare]
    def show_nas_share_by_pool(pool_id, nas_share_id, opts = {})
      data, _status_code, _headers = show_nas_share_by_pool_with_http_info(pool_id, nas_share_id, opts)
      data
    end

    # Displays a specific NAS share.
    # **API Key Scope**: nas_shares / show   Optional API Key Explicit Scope: nas_shares / get_password
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param [Hash] opts the optional parameters
    # @return [Array<(NasShare, Integer, Hash)>] NasShare data, response status code and response headers
    def show_nas_share_by_pool_with_http_info(pool_id, nas_share_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.show_nas_share_by_pool ...'
      end
      # verify the required parameter 'pool_id' is set
      if @api_client.config.client_side_validation && pool_id.nil?
        fail ArgumentError, "Missing the required parameter 'pool_id' when calling NasSharesApi.show_nas_share_by_pool"
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.show_nas_share_by_pool"
      end
      # resource path
      local_var_path = '/pools/{pool_id}/nas_shares/{nas_share_id}'.sub('{' + 'pool_id' + '}', CGI.escape(pool_id.to_s)).sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'NasShare' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#show_nas_share_by_pool\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Test an unsaved NAS Share.
    # **API Key Scope**: nas_shares / test
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [ActiveJobStatus]
    def test_nas_share(nas_id, nas_share_body, opts = {})
      data, _status_code, _headers = test_nas_share_with_http_info(nas_id, nas_share_body, opts)
      data
    end

    # Test an unsaved NAS Share.
    # **API Key Scope**: nas_shares / test
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(ActiveJobStatus, Integer, Hash)>] ActiveJobStatus data, response status code and response headers
    def test_nas_share_with_http_info(nas_id, nas_share_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.test_nas_share ...'
      end
      # verify the required parameter 'nas_id' is set
      if @api_client.config.client_side_validation && nas_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_id' when calling NasSharesApi.test_nas_share"
      end
      # verify the required parameter 'nas_share_body' is set
      if @api_client.config.client_side_validation && nas_share_body.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_body' when calling NasSharesApi.test_nas_share"
      end
      # resource path
      local_var_path = '/nas/{nas_id}/nas_shares/-/test'.sub('{' + 'nas_id' + '}', CGI.escape(nas_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json', 'queued', 'working', 'failed'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(nas_share_body) 

      # return_type
      return_type = opts[:return_type] || 'ActiveJobStatus' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#test_nas_share\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Check result of a NAS Share test job.
    # **API Key Scope**: nas_shares / test
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param job_id [String] ID of active job
    # @param [Hash] opts the optional parameters
    # @return [ActiveJobStatus]
    def test_result_nas_share(nas_id, job_id, opts = {})
      data, _status_code, _headers = test_result_nas_share_with_http_info(nas_id, job_id, opts)
      data
    end

    # Check result of a NAS Share test job.
    # **API Key Scope**: nas_shares / test
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param job_id [String] ID of active job
    # @param [Hash] opts the optional parameters
    # @return [Array<(ActiveJobStatus, Integer, Hash)>] ActiveJobStatus data, response status code and response headers
    def test_result_nas_share_with_http_info(nas_id, job_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.test_result_nas_share ...'
      end
      # verify the required parameter 'nas_id' is set
      if @api_client.config.client_side_validation && nas_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_id' when calling NasSharesApi.test_result_nas_share"
      end
      # verify the required parameter 'job_id' is set
      if @api_client.config.client_side_validation && job_id.nil?
        fail ArgumentError, "Missing the required parameter 'job_id' when calling NasSharesApi.test_result_nas_share"
      end
      # resource path
      local_var_path = '/nas/{nas_id}/nas_shares/-/test'.sub('{' + 'nas_id' + '}', CGI.escape(nas_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'job_id'] = job_id

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json', 'queued', 'working', 'failed'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'ActiveJobStatus' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#test_result_nas_share\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Updates a specific NAS share.
    # **API Key Scope**: nas_shares / update
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [NasShare]
    def update_nas_share(nas_share_id, nas_share_body, opts = {})
      data, _status_code, _headers = update_nas_share_with_http_info(nas_share_id, nas_share_body, opts)
      data
    end

    # Updates a specific NAS share.
    # **API Key Scope**: nas_shares / update
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(NasShare, Integer, Hash)>] NasShare data, response status code and response headers
    def update_nas_share_with_http_info(nas_share_id, nas_share_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.update_nas_share ...'
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.update_nas_share"
      end
      # verify the required parameter 'nas_share_body' is set
      if @api_client.config.client_side_validation && nas_share_body.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_body' when calling NasSharesApi.update_nas_share"
      end
      # resource path
      local_var_path = '/nas_shares/{nas_share_id}'.sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(nas_share_body) 

      # return_type
      return_type = opts[:return_type] || 'NasShare' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#update_nas_share\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Updates a specific NAS share.
    # **API Key Scope**: nas_shares / update
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [NasShare]
    def update_nas_share_by_nas(nas_id, nas_share_id, nas_share_body, opts = {})
      data, _status_code, _headers = update_nas_share_by_nas_with_http_info(nas_id, nas_share_id, nas_share_body, opts)
      data
    end

    # Updates a specific NAS share.
    # **API Key Scope**: nas_shares / update
    # @param nas_id [String] Numeric ID or name of NAS.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(NasShare, Integer, Hash)>] NasShare data, response status code and response headers
    def update_nas_share_by_nas_with_http_info(nas_id, nas_share_id, nas_share_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.update_nas_share_by_nas ...'
      end
      # verify the required parameter 'nas_id' is set
      if @api_client.config.client_side_validation && nas_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_id' when calling NasSharesApi.update_nas_share_by_nas"
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.update_nas_share_by_nas"
      end
      # verify the required parameter 'nas_share_body' is set
      if @api_client.config.client_side_validation && nas_share_body.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_body' when calling NasSharesApi.update_nas_share_by_nas"
      end
      # resource path
      local_var_path = '/nas/{nas_id}/nas_shares/{nas_share_id}'.sub('{' + 'nas_id' + '}', CGI.escape(nas_id.to_s)).sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(nas_share_body) 

      # return_type
      return_type = opts[:return_type] || 'NasShare' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#update_nas_share_by_nas\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Updates a specific NAS share.
    # **API Key Scope**: nas_shares / update
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [NasShare]
    def update_nas_share_by_pool(pool_id, nas_share_id, nas_share_body, opts = {})
      data, _status_code, _headers = update_nas_share_by_pool_with_http_info(pool_id, nas_share_id, nas_share_body, opts)
      data
    end

    # Updates a specific NAS share.
    # **API Key Scope**: nas_shares / update
    # @param pool_id [String] Numeric ID, or name of pool.
    # @param nas_share_id [String] Numeric ID or name of NAS share.
    # @param nas_share_body [NasShare] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(NasShare, Integer, Hash)>] NasShare data, response status code and response headers
    def update_nas_share_by_pool_with_http_info(pool_id, nas_share_id, nas_share_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: NasSharesApi.update_nas_share_by_pool ...'
      end
      # verify the required parameter 'pool_id' is set
      if @api_client.config.client_side_validation && pool_id.nil?
        fail ArgumentError, "Missing the required parameter 'pool_id' when calling NasSharesApi.update_nas_share_by_pool"
      end
      # verify the required parameter 'nas_share_id' is set
      if @api_client.config.client_side_validation && nas_share_id.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_id' when calling NasSharesApi.update_nas_share_by_pool"
      end
      # verify the required parameter 'nas_share_body' is set
      if @api_client.config.client_side_validation && nas_share_body.nil?
        fail ArgumentError, "Missing the required parameter 'nas_share_body' when calling NasSharesApi.update_nas_share_by_pool"
      end
      # resource path
      local_var_path = '/pools/{pool_id}/nas_shares/{nas_share_id}'.sub('{' + 'pool_id' + '}', CGI.escape(pool_id.to_s)).sub('{' + 'nas_share_id' + '}', CGI.escape(nas_share_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(nas_share_body) 

      # return_type
      return_type = opts[:return_type] || 'NasShare' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: NasSharesApi#update_nas_share_by_pool\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end
  end
end
