=begin
#Nodeum API

#The Nodeum API makes it easy to tap into the digital data mesh that runs across your organisation. Make requests to our API endpoints and we’ll give you everything you need to interconnect your business workflows with your storage.  All production API requests are made to:  http://nodeumhostname/api/  The current production version of the API is v1.   **REST** The Nodeum API is a RESTful API. This means that the API is designed to allow you to get, create, update, & delete objects with the HTTP verbs GET, POST, PUT, PATCH, & DELETE.  **JSON** The Nodeum API speaks exclusively in JSON. This means that you should always set the Content-Type header to application/json to ensure that your requests are properly accepted and processed by the API.  **Authentication** All API calls require user-password authentication.   **Cross-Origin Resource Sharing** The Nodeum API supports CORS for communicating from Javascript for these endpoints. You will need to specify an Origin URI when creating your application to allow for CORS to be whitelisted for your domain.   **Pagination** Some endpoints such as File Listing return a potentially lengthy array of objects. In order to keep the response sizes manageable the API will take advantage of pagination. Pagination is a mechanism for returning a subset of the results for a request and allowing for subsequent requests to “page” through the rest of the results until the end is reached. Paginated endpoints follow a standard interface that accepts two query parameters, limit and offset, and return a payload that follows a standard form. These parameters names and their behavior are borrowed from SQL LIMIT and OFFSET keywords.  **Versioning** The Nodeum API is constantly being worked on to add features, make improvements, and fix bugs. This means that you should expect changes to be introduced and documented.   However, there are some changes or additions that are considered backwards-compatible and your applications should be flexible enough to handle them. These include:  - Adding new endpoints to the API - Adding new attributes to the response of an existing endpoint - Changing the order of attributes of responses (JSON by definition is an object of unordered key/value pairs)  **Filter parameters** When browsing a list of items, multiple filter parameters may be applied. Some operators can be added to the value as a prefix:  - `=` value is equal. Default operator, may be omitted  - `!=` value is different  - `>` greater than  - `>=` greater than or equal  - `<` lower than  - `>=` lower than or equal  - `><` included in list, items should be separated by `|`  - `!><` not included in list, items should be separated by `|`  - `~` pattern matching, may include `%` (any characters) and `_` (one character)  - `!~` pattern not matching, may include `%` (any characters) and `_` (one character)  

The version of the OpenAPI document: 2.1.0
Contact: info@nodeum.io
Generated by: https://openapi-generator.tech
OpenAPI Generator version: 4.3.0

=end

require 'cgi'

module Nodeum
  class TaskDestinationsApi
    attr_accessor :api_client

    def initialize(api_client = ApiClient.default)
      @api_client = api_client
    end
    # Creates a new task destination.
    # **API Key Scope**: task_destinations / create
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param task_destination_body [TaskDestinationUp] 
    # @param [Hash] opts the optional parameters
    # @return [TaskDestinationDown]
    def create_task_destination(task_id, task_destination_body, opts = {})
      data, _status_code, _headers = create_task_destination_with_http_info(task_id, task_destination_body, opts)
      data
    end

    # Creates a new task destination.
    # **API Key Scope**: task_destinations / create
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param task_destination_body [TaskDestinationUp] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(TaskDestinationDown, Integer, Hash)>] TaskDestinationDown data, response status code and response headers
    def create_task_destination_with_http_info(task_id, task_destination_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TaskDestinationsApi.create_task_destination ...'
      end
      # verify the required parameter 'task_id' is set
      if @api_client.config.client_side_validation && task_id.nil?
        fail ArgumentError, "Missing the required parameter 'task_id' when calling TaskDestinationsApi.create_task_destination"
      end
      # verify the required parameter 'task_destination_body' is set
      if @api_client.config.client_side_validation && task_destination_body.nil?
        fail ArgumentError, "Missing the required parameter 'task_destination_body' when calling TaskDestinationsApi.create_task_destination"
      end
      # resource path
      local_var_path = '/tasks/{task_id}/task_destinations'.sub('{' + 'task_id' + '}', CGI.escape(task_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(task_destination_body) 

      # return_type
      return_type = opts[:return_type] || 'TaskDestinationDown' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TaskDestinationsApi#create_task_destination\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Destroys a specific task destination.
    # **API Key Scope**: task_destinations / destroy
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param task_destination_id [Integer] Numeric ID of task destination.
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def destroy_task_destination(task_id, task_destination_id, opts = {})
      destroy_task_destination_with_http_info(task_id, task_destination_id, opts)
      nil
    end

    # Destroys a specific task destination.
    # **API Key Scope**: task_destinations / destroy
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param task_destination_id [Integer] Numeric ID of task destination.
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
    def destroy_task_destination_with_http_info(task_id, task_destination_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TaskDestinationsApi.destroy_task_destination ...'
      end
      # verify the required parameter 'task_id' is set
      if @api_client.config.client_side_validation && task_id.nil?
        fail ArgumentError, "Missing the required parameter 'task_id' when calling TaskDestinationsApi.destroy_task_destination"
      end
      # verify the required parameter 'task_destination_id' is set
      if @api_client.config.client_side_validation && task_destination_id.nil?
        fail ArgumentError, "Missing the required parameter 'task_destination_id' when calling TaskDestinationsApi.destroy_task_destination"
      end
      # resource path
      local_var_path = '/tasks/{task_id}/task_destinations/{task_destination_id}'.sub('{' + 'task_id' + '}', CGI.escape(task_id.to_s)).sub('{' + 'task_destination_id' + '}', CGI.escape(task_destination_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TaskDestinationsApi#destroy_task_destination\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Lists all task destinations.
    # **API Key Scope**: task_destinations / index
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :folder_id Filter on folder id
    # @option opts [String] :tape_id Filter on tape id
    # @option opts [String] :pool_id Filter on a pool id
    # @return [TaskDestinationCollection]
    def index_task_destinations(task_id, opts = {})
      data, _status_code, _headers = index_task_destinations_with_http_info(task_id, opts)
      data
    end

    # Lists all task destinations.
    # **API Key Scope**: task_destinations / index
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param [Hash] opts the optional parameters
    # @option opts [Integer] :limit The number of items to display for pagination.
    # @option opts [Integer] :offset The number of items to skip for pagination.
    # @option opts [Array<String>] :sort_by Sort results by attribute.  Can sort on multiple attributes, separated by &#x60;|&#x60;. Order direction can be suffixing the attribute by either &#x60;:asc&#x60; (default) or &#x60;:desc&#x60;.
    # @option opts [String] :id Filter on id
    # @option opts [String] :folder_id Filter on folder id
    # @option opts [String] :tape_id Filter on tape id
    # @option opts [String] :pool_id Filter on a pool id
    # @return [Array<(TaskDestinationCollection, Integer, Hash)>] TaskDestinationCollection data, response status code and response headers
    def index_task_destinations_with_http_info(task_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TaskDestinationsApi.index_task_destinations ...'
      end
      # verify the required parameter 'task_id' is set
      if @api_client.config.client_side_validation && task_id.nil?
        fail ArgumentError, "Missing the required parameter 'task_id' when calling TaskDestinationsApi.index_task_destinations"
      end
      # resource path
      local_var_path = '/tasks/{task_id}/task_destinations'.sub('{' + 'task_id' + '}', CGI.escape(task_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
      query_params[:'sort_by'] = @api_client.build_collection_param(opts[:'sort_by'], :pipe) if !opts[:'sort_by'].nil?
      query_params[:'id'] = opts[:'id'] if !opts[:'id'].nil?
      query_params[:'folder_id'] = opts[:'folder_id'] if !opts[:'folder_id'].nil?
      query_params[:'tape_id'] = opts[:'tape_id'] if !opts[:'tape_id'].nil?
      query_params[:'pool_id'] = opts[:'pool_id'] if !opts[:'pool_id'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'TaskDestinationCollection' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TaskDestinationsApi#index_task_destinations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Displays a specific task destination.
    # **API Key Scope**: task_destinations / show
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param task_destination_id [Integer] Numeric ID of task destination.
    # @param [Hash] opts the optional parameters
    # @return [TaskDestinationDown]
    def show_task_destination(task_id, task_destination_id, opts = {})
      data, _status_code, _headers = show_task_destination_with_http_info(task_id, task_destination_id, opts)
      data
    end

    # Displays a specific task destination.
    # **API Key Scope**: task_destinations / show
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param task_destination_id [Integer] Numeric ID of task destination.
    # @param [Hash] opts the optional parameters
    # @return [Array<(TaskDestinationDown, Integer, Hash)>] TaskDestinationDown data, response status code and response headers
    def show_task_destination_with_http_info(task_id, task_destination_id, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TaskDestinationsApi.show_task_destination ...'
      end
      # verify the required parameter 'task_id' is set
      if @api_client.config.client_side_validation && task_id.nil?
        fail ArgumentError, "Missing the required parameter 'task_id' when calling TaskDestinationsApi.show_task_destination"
      end
      # verify the required parameter 'task_destination_id' is set
      if @api_client.config.client_side_validation && task_destination_id.nil?
        fail ArgumentError, "Missing the required parameter 'task_destination_id' when calling TaskDestinationsApi.show_task_destination"
      end
      # resource path
      local_var_path = '/tasks/{task_id}/task_destinations/{task_destination_id}'.sub('{' + 'task_id' + '}', CGI.escape(task_id.to_s)).sub('{' + 'task_destination_id' + '}', CGI.escape(task_destination_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] 

      # return_type
      return_type = opts[:return_type] || 'TaskDestinationDown' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TaskDestinationsApi#show_task_destination\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Updates a specific task destination.
    # **API Key Scope**: task_destinations / update
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param task_destination_id [Integer] Numeric ID of task destination.
    # @param task_destination_body [TaskDestinationUp] 
    # @param [Hash] opts the optional parameters
    # @return [TaskDestinationDown]
    def update_task_destination(task_id, task_destination_id, task_destination_body, opts = {})
      data, _status_code, _headers = update_task_destination_with_http_info(task_id, task_destination_id, task_destination_body, opts)
      data
    end

    # Updates a specific task destination.
    # **API Key Scope**: task_destinations / update
    # @param task_id [String] Numeric ID or name of task. Task names are not unique, it&#39;s recommanded to use numeric ID.
    # @param task_destination_id [Integer] Numeric ID of task destination.
    # @param task_destination_body [TaskDestinationUp] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(TaskDestinationDown, Integer, Hash)>] TaskDestinationDown data, response status code and response headers
    def update_task_destination_with_http_info(task_id, task_destination_id, task_destination_body, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TaskDestinationsApi.update_task_destination ...'
      end
      # verify the required parameter 'task_id' is set
      if @api_client.config.client_side_validation && task_id.nil?
        fail ArgumentError, "Missing the required parameter 'task_id' when calling TaskDestinationsApi.update_task_destination"
      end
      # verify the required parameter 'task_destination_id' is set
      if @api_client.config.client_side_validation && task_destination_id.nil?
        fail ArgumentError, "Missing the required parameter 'task_destination_id' when calling TaskDestinationsApi.update_task_destination"
      end
      # verify the required parameter 'task_destination_body' is set
      if @api_client.config.client_side_validation && task_destination_body.nil?
        fail ArgumentError, "Missing the required parameter 'task_destination_body' when calling TaskDestinationsApi.update_task_destination"
      end
      # resource path
      local_var_path = '/tasks/{task_id}/task_destinations/{task_destination_id}'.sub('{' + 'task_id' + '}', CGI.escape(task_id.to_s)).sub('{' + 'task_destination_id' + '}', CGI.escape(task_destination_id.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:body] || @api_client.object_to_http_body(task_destination_body) 

      # return_type
      return_type = opts[:return_type] || 'TaskDestinationDown' 

      # auth_names
      auth_names = opts[:auth_names] || ['BasicAuth', 'BearerAuth']

      new_options = opts.merge(
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TaskDestinationsApi#update_task_destination\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end
  end
end
